==> haskell-dns-2.0.10-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.10
id: dns-2.0.10-4hbaL7YS5O2HKGxYSZKGCX
key: dns-2.0.10-4hbaL7YS5O2HKGxYSZKGCX
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: 3699915eb2dc50c5f9a7cf2af3d4e836
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/dns-2.0.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/dns-2.0.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/dns-2.0.10
hs-libraries: HSdns-2.0.10-4hbaL7YS5O2HKGxYSZKGCX
depends:
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    binary-0.8.3.0 bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-9cN22ayihO7Dd9VUMeez1K containers-0.5.7.1
    iproute-1.7.1-9hsGfRvggCmFA0ueZi5Sd9
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    random-1.1-54KmMHXjttlERYcr1mvsAe
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    safe-0.3.10-1VyrsjWhmjvGnGud5lgW7f
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-2.0.10-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.10
id: dns-2.0.10-5HhLM3K3xba6v0kxT7JBkY
key: dns-2.0.10-5HhLM3K3xba6v0kxT7JBkY
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: 78b78fd818a3b8b22051284e92b944bb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/dns-2.0.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/dns-2.0.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/dns-2.0.10
hs-libraries: HSdns-2.0.10-5HhLM3K3xba6v0kxT7JBkY
depends:
    attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat base-4.9.0.0
    binary-0.8.3.0 bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-824iGXaP3tL2Ph4TH8girc containers-0.5.7.1
    iproute-1.7.1-9hsGfRvggCmFA0ueZi5Sd9
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    random-1.1-54KmMHXjttlERYcr1mvsAe
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    safe-0.3.11-Ck0Z7kfzoQA1bcHU9bHvtW
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
